@@ -8,8 +8,8 @@ class Version(object):
     '''
     Version handling for pyGenericSpreadSheet
     '''
-    version='0.1.4'
+    version='0.1.5'
     date = '2022-04-21'
-    updated = '2022-07-30'
+    updated = '2022-07-31'
     name='pyGenericSpreadSheet'
-    description='python API providing generic Access to Spreadsheet backends'
\ No newline at end of file
+    description='python API providing generic Access to specific Spreadsheet backends'
\ No newline at end of file
